leap.mail
=========
Mail services for the LEAP Client.

.. image:: https://pypip.in/v/leap.mail/badge.png
        :target: https://crate.io/packages/leap.mail

.. image:: https://readthedocs.org/projects/leapmail/badge/?version=latest
         :target: http://leapmail.readthedocs.org/en/latest/
         :alt: Documentation Status

More info: https://leap.se

running tests
-------------

Use trial to run the test suite::

  trial leap.mail

... and all its goodies. To run all imap tests in a loop until some of them
fails::

  trial -u leap.mail.imap

Read the *trial* manpage for more options .
